@@ -32,7 +32,7 @@
 #' Ishwaran H. (2007). Variable importance in binary regression trees and forests, 
 #' \emph{Electronic J. Statist.}, 1:519-537.
 #' 
-#' @importFrom tidyr gather
+#' @importFrom tidyr gather_
 #' @importFrom dplyr arrange desc %>%
 #' 
 #' @examples
@@ -41,8 +41,8 @@
 #' ## ------------------------------------------------------------
 #' # iris_rf <- rfsrc(Species ~ ., data = iris)
 #' data(iris_rf, package="ggRandomForests")
-#' ggrf <- gg_vimp(iris_rf)
-#' plot(ggrf)
+#' gg_dta <- gg_vimp(iris_rf)
+#' plot(gg_dta)
 #'  
 #' ## ------------------------------------------------------------
 #' ## regression example
@@ -50,15 +50,15 @@
 #' 
 #' # airq.obj <- rfsrc(Ozone ~ ., airquality)
 #' data(airq_rf, package="ggRandomForests")
-#' ggrf <- gg_vimp(airq_rf)
-#' plot(ggrf)
+#' gg_dta <- gg_vimp(airq_rf)
+#' plot(gg_dta)
 #' 
 #' ## ------------------------------------------------------------
 #' ## survival example
 #' ## ------------------------------------------------------------
 #' data(veteran_rf, package="ggRandomForests")
-#' ggrf <- gg_vimp(veteran_rf)
-#' plot(ggrf)
+#' gg_dta <- gg_vimp(veteran_rf)
+#' plot(gg_dta)
 #' 
 #' @export gg_vimp.ggRandomForests
 #' @export gg_vimp
@@ -78,37 +78,34 @@ gg_vimp.ggRandomForests <- function(object, ...){
   ### set importance to NA if it is NULL
   if (is.null(object$importance)){
     warning("rfsrc object does not contain VIMP information. Calculating...")
-    imp <- data.frame(sort(vimp(object, ...)$importance, decreasing=TRUE))
+    gg_dta <- data.frame(sort(vimp(object, ...)$importance, decreasing=TRUE))
   }else{
-    imp <- object$importance
+    gg_dta <- object$importance
   }
   
   # Handle multiclass importance
-  if(!is.null(dim(imp))){
-    imp <- data.frame(imp)
-    imp$vars <- rownames(imp)
-    imp <- imp %>% gather(cls,vimp, -vars) %>% arrange(desc(vimp))
-    colnames(imp)[2] <- "set"
-    imp$vars <- factor(imp$vars)
-  }else{
-    imp <- data.frame(sort(imp, decreasing=TRUE))
+  if(!is.null(dim(gg_dta))){
+    gg_dta <- data.frame(gg_dta)
+    gg_dta$vars <- rownames(gg_dta)
     
-    imp<- cbind(imp, imp/imp[1,1])
-    colnames(imp) <- c("vimp", "rel_vimp")
-    imp$vars <- rownames(imp)
-    imp$vars[which(is.na(imp$vars))] <- rownames(imp)[which(is.na(imp$vars))]
+    clnms <- colnames(gg_dta)[-which(colnames(gg_dta)=="vars")]
+    gg_dta <- gg_dta %>% gather(cls, vimp, -vars) %>% arrange(desc(vimp))
+    colnames(gg_dta)[2] <- "set"
+    gg_dta$vars <- factor(gg_dta$vars)
+  }else{
+    gg_dta <- data.frame(sort(gg_dta, decreasing=TRUE))
+    
+    gg_dta<- cbind(gg_dta, gg_dta/gg_dta[1,1])
+    colnames(gg_dta) <- c("vimp", "rel_vimp")
+    gg_dta$vars <- rownames(gg_dta)
+    gg_dta$vars[which(is.na(gg_dta$vars))] <- rownames(gg_dta)[which(is.na(gg_dta$vars))]
   }
-  imp$vars <- factor(imp$vars, levels=rev(unique(imp$vars)))
-  imp$positive <- TRUE
-  imp$positive[which(imp$vimp <=0)] <- FALSE
-  #   
-  #     if(missing(xvar.vars)){
-  #       rfvimp <- as.data.frame(cbind(rfvimp[order(rfvimp, decreasing=TRUE)][1:n.var]))
-  #     }else{
-  #       rfvimp <- rfvimp[which(vars(rfvimp) %in% var.vars)]
-  #     }
-  class(imp) <- c("gg_vimp", class(imp))
-  invisible(imp)
+  gg_dta$vars <- factor(gg_dta$vars, levels=rev(unique(gg_dta$vars)))
+  gg_dta$positive <- TRUE
+  gg_dta$positive[which(gg_dta$vimp <=0)] <- FALSE
+  
+  class(gg_dta) <- c("gg_vimp", class(gg_dta))
+  invisible(gg_dta)
 }
 
 gg_vimp <-gg_vimp.ggRandomForests
