@@ -22,10 +22,11 @@
 #' @param x \code{\link{gg_minimal_depth}} object created from a \code{randomForestSRC::var.select} 
 #' object
 #' @param modelsize should the figure be restricted to a subset of the points.
+#' @param lbls a vector of alternative variable names.
 #' @param ... optional arguments (not used)
 #' 
 #' @export plot.gg_minimal_vimp
-#' @importFrom ggplot2 ggplot aes_string geom_point labs geom_abline coord_flip
+#' @importFrom ggplot2 ggplot aes_string geom_point labs geom_abline coord_flip scale_x_discrete
 #'
 #' @seealso \code{\link{gg_minimal_vimp}} \code{randomForestSRC::var.select}
 #'  
@@ -42,10 +43,10 @@
 #' data(iris_vs, package="ggRandomForests")
 #' 
 #' # Get a data.frame containing minimaldepth measures
-#' ggrf.obj<- gg_minimal_vimp(iris_vs)
+#' gg_dta<- gg_minimal_vimp(iris_vs)
 #' 
 #' # Plot the gg_mkinimal_depth object
-#' plot(ggrf.obj)
+#' plot(gg_dta)
 #' 
 #' ## ------------------------------------------------------------
 #' ## Regression example
@@ -56,10 +57,10 @@
 #' data(airq_vs, package="ggRandomForests")
 #' 
 #' # Get a data.frame containing error rates
-#' ggrf.obj<- gg_minimal_vimp(airq_vs)
+#' gg_dta<- gg_minimal_vimp(airq_vs)
 #' 
 #' # Plot the gg_error object
-#' plot(ggrf.obj)
+#' plot(gg_dta)
 #' 
 #' ## ------------------------------------------------------------
 #' ## Survival example
@@ -72,40 +73,49 @@
 #' # Load a cached randomForestSRC object
 #' data(veteran_vs, package="ggRandomForests")
 #' 
-#' ggrf.obj <- gg_minimal_vimp(veteran_vs)
-#' plot(ggrf.obj)
+#' gg_dta <- gg_minimal_vimp(veteran_vs)
+#' plot(gg_dta)
 #' } 
-plot.gg_minimal_vimp <- function(x, modelsize, ...){
-  object <- x
+plot.gg_minimal_vimp <- function(x, modelsize, lbls, ...){
+  gg_dta <- x
   
   # Test that object is the correct class object
-  if(!inherits(object, "gg_minimal_vimp")){
-    object <- gg_minimal_vimp(x, ...)
+  if(!inherits(gg_dta, "gg_minimal_vimp")){
+    gg_dta <- gg_minimal_vimp(x, ...)
   }
   
-  if(missing(modelsize)) modelsize <- dim(object)[1]
-  if(modelsize > dim(object)[1]) modelsize <- dim(object)[1]
-  if(length(unique(object$col)) > 1){
-    object$col <- factor(object$col)
+  if(missing(modelsize)) modelsize <- dim(gg_dta)[1]
+  if(modelsize > dim(gg_dta)[1]) modelsize <- dim(gg_dta)[1]
+  if(length(unique(gg_dta$col)) > 1){
+    gg_dta$col <- factor(gg_dta$col)
   }
-  object$names <- factor(object$names, 
-                         levels=object$names[order(as.numeric(object$depth))])
+  gg_dta$names <- factor(gg_dta$names, 
+                         levels=gg_dta$names[order(as.numeric(gg_dta$depth))])
   
-  object <- object[1:modelsize, ]
+  gg_dta <- gg_dta[1:modelsize, ]
   
   # If we only have one class for coloring, just paint them black.
-  if(length(unique(object$col)) > 1){
-    gg_dta <- ggplot(object, aes_string(x="names", y="vimp", col="col"))+
-      geom_point()+
-      labs(x="Minimal Depth (Rank Order)", y="VIMP Rank", color="VIMP")+
-      geom_abline(xintercept=0, slope=1, col="red", size=.5, linetype=2)+
-      coord_flip()
+  if(length(unique(gg_dta$col)) > 1){
+    gg_plt <- ggplot(gg_dta, aes_string(x="names", y="vimp", col="col"))+
+      labs(x="Minimal Depth (Rank Order)", y="VIMP Rank", color="VIMP")
+    
   }else{
-    gg_dta <- ggplot(object, aes_string(x="names", y="vimp"))+
-      geom_point()+
-      labs(x="Minimal Depth (Rank Order)", y="VIMP Rank")+
-      geom_abline(xintercept=0, slope=1, col="red", size=.5, linetype=2)+
-      coord_flip()
+    gg_plt <- ggplot(gg_dta, aes_string(x="names", y="vimp"))+
+      labs(x="Minimal Depth (Rank Order)", y="VIMP Rank")
   }
-  gg_dta
+  if(!missing(lbls)){
+    if(length(lbls) >= length(gg_dta$names)){
+      st.lbls <- lbls[as.character(gg_dta$names)]
+      names(st.lbls) <- as.character(gg_dta$names)
+      st.lbls[which(is.na(st.lbls))] <- names(st.lbls[which(is.na(st.lbls))])
+      
+      gg_plt <- gg_plt +
+        scale_x_discrete(labels=st.lbls)
+    }
+  }
+  
+  gg_plt + geom_point()+
+    geom_abline(xintercept=0, slope=1, col="red", size=.5, linetype=2)+
+    coord_flip()
+  
 }
\ No newline at end of file
