@@ -41,6 +41,7 @@
 #' and Classification (RF-SRC), R package version 1.4.
 #' 
 #' @importFrom ggplot2 ggplot aes_string geom_point geom_smooth labs facet_wrap
+#' @importFrom parallel mclapply
 #' 
 #' @examples
 #' \dontrun{
@@ -60,23 +61,23 @@
 #' ## airquality
 #' #airq.obj <- rfsrc(Ozone ~ ., data = airquality)
 #' data(airq_rf, package="ggRandomForests")
-#' ggrf <- gg_variable(airq_rf)
-#' plot(ggrf, x_var="Wind")
-#' plot(ggrf, x_var="Temp")
-#' plot(ggrf, x_var="Solar.R")
+#' gg_dta <- gg_variable(airq_rf)
+#' plot(gg_dta, x_var="Wind")
+#' plot(gg_dta, x_var="Temp")
+#' plot(gg_dta, x_var="Solar.R")
 #' 
 #' ## motor trend cars
 #' #mtcars.obj <- rfsrc(mpg ~ ., data = mtcars)
 #' data(mtcars_rf, package="ggRandomForests")
-#' ggrf <- gg_variable(mtcars_rf)
+#' gg_dta <- gg_variable(mtcars_rf)
 #' 
 #' # mtcars$cyl is an ordinal variable
-#' plot(ggrf, x_var="cyl")
+#' plot(gg_dta, x_var="cyl")
 #' 
 #' # Others are continuous
-#' plot(ggrf, x_var="disp")
-#' plot(ggrf, x_var="hp")
-#' plot(ggrf, x_var="wt")
+#' plot(gg_dta, x_var="disp")
+#' plot(gg_dta, x_var="hp")
+#' plot(gg_dta, x_var="wt")
 #' 
 #' ## ------------------------------------------------------------
 #' ## survival examples
@@ -88,19 +89,19 @@
 #' data(veteran_rf, package="ggRandomForests")
 #' 
 #' # get the 30 day survival time.
-#' ggrf <- gg_variable(veteran_rf, time=30)
+#' gg_dta <- gg_variable(veteran_rf, time=30)
 #' 
 #' # Generate variable dependance plots for age and diagtime
-#' plot(ggrf, x_var = "age")
-#' plot(ggrf, x_var = "diagtime")
+#' plot(gg_dta, x_var = "age")
+#' plot(gg_dta, x_var = "diagtime")
 #' 
 #' # If we want to compare survival at different time points, say 30, 90 day 
 #' # and 1 year
-#' ggrf <- gg_variable(veteran_rf, time=c(30, 90, 365))
+#' gg_dta <- gg_variable(veteran_rf, time=c(30, 90, 365))
 #' 
 #' # Generate variable dependance plots for age and diagtime
-#' plot(ggrf, x_var = "age")
-#' plot(ggrf, x_var = "diagtime") 
+#' plot(gg_dta, x_var = "age")
+#' plot(gg_dta, x_var = "diagtime") 
 #'
 #' }
 ### error rate plot
@@ -108,43 +109,43 @@ plot.gg_variable<- function(x, x_var,
                             time, time_labels, 
                             panel=FALSE,
                             oob=TRUE, smooth=TRUE,  ...){
-  object <- x 
-  if(inherits(x, "rfsrc")) object <- gg_variable(x, ...)
+  gg_dta <- x 
+  if(inherits(x, "rfsrc")) gg_dta <- gg_variable(x, ...)
 
-  if(inherits(object, "surv")){
+  if(inherits(gg_dta, "surv")){
     family <- "surv"
-  }else if(inherits(object, "regr")){
+  }else if(inherits(gg_dta, "regr")){
     family <- "regr"
   }else{
     family <- "class"
   }
-  if(length(grep("yhat.", colnames(object))) > 0){
+  if(length(grep("yhat.", colnames(gg_dta))) > 0){
     # We have a classification forest with multiple outcomes.
-    if(length(grep("yhat.", colnames(object))) == 2){
+    if(length(grep("yhat.", colnames(gg_dta))) == 2){
       # For the case of two, we are only interested in the TRUE, not FALSE.
-      object  <- object[, -grep("yhat.", colnames(object))[1]]
-      colnames(object)[grep("yhat.", colnames(object))] <- "yhat"
+      gg_dta  <- gg_dta[, -grep("yhat.", colnames(gg_dta))[1]]
+      colnames(gg_dta)[grep("yhat.", colnames(gg_dta))] <- "yhat"
     }else{
       # Else we want to split and duplicate the data... make it long format.
-      objectX <- object[, -grep("yhat.", colnames(object))]
-      objectY <- object[, grep("yhat.", colnames(object))]
-      lng <- ncol(objectY)
-      gg2 <- lapply(1:ncol(objectY),
-                    function(ind){cbind(objectX, yhat=objectY[,ind], outcome=ind)})
+      gg_dtaX <- gg_dta[, -grep("yhat.", colnames(gg_dta))]
+      gg_dtaY <- gg_dta[, grep("yhat.", colnames(gg_dta))]
+      lng <- ncol(gg_dtaY)
+      gg2 <- mclapply(1:ncol(gg_dtaY),
+                    function(ind){cbind(gg_dtaX, yhat=gg_dtaY[,ind], outcome=ind)})
       gg3 <- do.call(rbind,gg2)
       gg3$outcome <- factor(gg3$outcome)
-      object <- gg3 
+      gg_dta <- gg3 
     }
-    # print(object)
+    # print(gg_dta)
   }
   
-  if(sum(colnames(object) == "cens") != 0) family <- "surv"
+  if(sum(colnames(gg_dta) == "cens") != 0) family <- "surv"
   
   if(missing(x_var)){
     # We need to remove response variables here
-    cls <- c(grep("yhat", colnames(object)),
-             grep("cens", colnames(object)))
-    x_var <- colnames(object)[-cls]
+    cls <- c(grep("yhat", colnames(gg_dta)),
+             grep("cens", colnames(gg_dta)))
+    x_var <- colnames(gg_dta)[-cls]
   }
   
   lng <- length(x_var)
@@ -154,124 +155,124 @@ plot.gg_variable<- function(x, x_var,
     if(family == "surv"){
       variable <- value <- time <- yhat <- cens <- NA
       ## Create a panel plot
-      wchXvar <- which(colnames(object) %in% x_var)
+      wchXvar <- which(colnames(gg_dta) %in% x_var)
       
-      wchYvar <- which(colnames(object) %in% c("cens", "yhat", "time"))
+      wchYvar <- which(colnames(gg_dta) %in% c("cens", "yhat", "time"))
       
-      dataObject <- object %>% select(c(wchYvar, wchXvar)) %>%
+      gg_dta.mlt <- gg_dta %>% select(c(wchYvar, wchXvar)) %>%
         gather(variable, value,-time, -yhat, -cens)
       
-      gDta <- ggplot(dataObject)+
+      gg_plt <- ggplot(gg_dta.mlt)+
         labs(y= "Survival") +
         geom_point(aes_string(x="value", y="yhat", color="cens", shape="cens"), 
                    ...)
       
       if(smooth){
-        gDta <- gDta +
+        gg_plt <- gg_plt +
           geom_smooth(aes_string(x="value", y="yhat"), ...)
       }
-      if(length(levels(object$time)) > 1){
-        gDta<- gDta+
+      if(length(levels(gg_dta$time)) > 1){
+        gg_plt<- gg_plt+
           facet_grid(reformulate("variable", "time"),
                      scales="free_x")+
           labs(x="")
       }else{
-        gDta<- gDta + 
+        gg_plt<- gg_plt + 
           facet_wrap(~variable,
                      scales="free_x")+
-          labs(x="",y= paste("Survival at", object$time[1], "year"))
+          labs(x="",y= paste("Survival at", gg_dta$time[1], "year"))
       }
       
     }else{
       # This will work for regression and binary classification... maybe.
       variable <- value <- yhat <- NA
       ## Create a panel plot
-      wchXvar <- which(colnames(object) %in% x_var)
+      wchXvar <- which(colnames(gg_dta) %in% x_var)
       
-      wchYvar <- which(colnames(object) %in% c("yhat"))
+      wchYvar <- which(colnames(gg_dta) %in% c("yhat"))
       
-      dataObject <- object %>% select(c(wchYvar, wchXvar)) %>%
+      gg_dta.mlt <- gg_dta %>% select(c(wchYvar, wchXvar)) %>%
         gather(variable, value, -yhat)
       
-      dataObject$variable <- factor(dataObject$variable,
-                                    levels=unique(dataObject$variable))
+      gg_dta.mlt$variable <- factor(gg_dta.mlt$variable,
+                                    levels=unique(gg_dta.mlt$variable))
       
-      gDta <- ggplot(dataObject)+
+      gg_plt <- ggplot(gg_dta.mlt)+
         geom_point(aes_string(x="value", y="yhat"), 
                    ...)
       
       if(smooth){
-        gDta <- gDta +
+        gg_plt <- gg_plt +
           geom_smooth(aes_string(x="value", y="yhat"), ...)
       }
       
-      gDta <- gDta +
+      gg_plt <- gg_plt +
         facet_wrap(~variable,
                    scales="free_x")+
         labs(x="")
     }
   }else{
     # Plot or list of plots.
-    gDta <- vector("list", length=lng)
+    gg_plt <- vector("list", length=lng)
     
     for(ind in 1:lng){
-      chIndx <- which(colnames(object)==x_var[ind])
-      hName <- colnames(object)[chIndx]
-      colnames(object)[chIndx] <- "var"
-      ccls <- class(object[,"var"])
+      chIndx <- which(colnames(gg_dta)==x_var[ind])
+      hName <- colnames(gg_dta)[chIndx]
+      colnames(gg_dta)[chIndx] <- "var"
+      ccls <- class(gg_dta[,"var"])
       
       # Check for logicals...
-      if(length(unique(object[,"var"])) < 3 & ccls =="numeric" ){
+      if(length(unique(gg_dta[,"var"])) < 3 & ccls =="numeric" ){
         ccls <- "logical"
-        object[,"var"] <- as.logical(object[,"var"])
+        gg_dta[,"var"] <- as.logical(gg_dta[,"var"])
       } 
-      gDta[[ind]] <- ggplot(object)
+      gg_plt[[ind]] <- ggplot(gg_dta)
       
       if(family == "surv"){
-        gDta[[ind]] <- gDta[[ind]]+
+        gg_plt[[ind]] <- gg_plt[[ind]]+
           labs(x=hName, y= "Survival")
         if(ccls=="numeric"){
-          gDta[[ind]] <- gDta[[ind]]+
+          gg_plt[[ind]] <- gg_plt[[ind]]+
             geom_point(aes_string(x="var", y="yhat", color="cens", shape="cens"), 
                        ...)
           
           if(smooth){
             
-            gDta[[ind]] <- gDta[[ind]] +
+            gg_plt[[ind]] <- gg_plt[[ind]] +
               geom_smooth(aes_string(x="var", y="yhat"), ...)
             
           }
         }else{
-          gDta[[ind]] <- gDta[[ind]]+
+          gg_plt[[ind]] <- gg_plt[[ind]]+
             geom_boxplot(aes_string(x="var", y="yhat"), color="grey",
                          ...,outlier.shape = NA)+
             geom_jitter(aes_string(x="var", y="yhat", color="cens", shape="cens"), 
                         ...)
           
         }
-        if(length(levels(object$time)) > 1){
-          gDta[[ind]]<- gDta[[ind]] + facet_wrap(~time, ncol=1)
+        if(length(levels(gg_dta$time)) > 1){
+          gg_plt[[ind]]<- gg_plt[[ind]] + facet_wrap(~time, ncol=1)
         }else{
-          gDta[[ind]]<- gDta[[ind]] + 
-            labs(x=hName, y= paste("Survival at", object$time[1], "year"))
+          gg_plt[[ind]]<- gg_plt[[ind]] + 
+            labs(x=hName, y= paste("Survival at", gg_dta$time[1], "year"))
         }
       }else if(family == "class"){
-        gDta[[ind]] <- gDta[[ind]] +
+        gg_plt[[ind]] <- gg_plt[[ind]] +
           labs(x=hName, y="Predicted")
         
-        if(sum(colnames(object) == "outcome") ==0){ 
+        if(sum(colnames(gg_dta) == "outcome") ==0){ 
           if(ccls=="numeric"){
-            gDta[[ind]] <- gDta[[ind]] +
+            gg_plt[[ind]] <- gg_plt[[ind]] +
               geom_point(aes_string(x="var", y="yhat", color="yvar", shape="yvar"),
                          ...)
             
             if(smooth){
               
-              gDta[[ind]] <- gDta[[ind]] +
+              gg_plt[[ind]] <- gg_plt[[ind]] +
                 geom_smooth(aes_string(x="var", y="yhat"), ...)
             }
           }else{
-            gDta[[ind]] <- gDta[[ind]]+
+            gg_plt[[ind]] <- gg_plt[[ind]]+
               geom_boxplot(aes_string(x="var", y="yhat"), color="grey", 
                            ..., outlier.shape = NA)+
               geom_jitter(aes_string(x="var", y="yhat", color="yvar", shape="yvar"), 
@@ -281,12 +282,12 @@ plot.gg_variable<- function(x, x_var,
         }else{
           
           if(ccls=="numeric"){
-            gDta[[ind]] <- gDta[[ind]] +
+            gg_plt[[ind]] <- gg_plt[[ind]] +
               geom_point(aes_string(x="var", y="yhat", color="yvar", shape="yvar"),
                          ...)
             
           }else{
-            gDta[[ind]] <- gDta[[ind]]+
+            gg_plt[[ind]] <- gg_plt[[ind]]+
               geom_boxplot(aes_string(x="var", y="yhat"), color="grey", 
                            ..., outlier.shape = NA)+
               geom_jitter(aes_string(x="var", y="yhat", color="yvar", shape="yvar"), 
@@ -294,34 +295,34 @@ plot.gg_variable<- function(x, x_var,
             
           }
           
-          gDta[[ind]] <- gDta[[ind]] + facet_grid(~outcome)
+          gg_plt[[ind]] <- gg_plt[[ind]] + facet_grid(~outcome)
         }
       }else{
         # assume regression
-        gDta[[ind]] <- gDta[[ind]] +
+        gg_plt[[ind]] <- gg_plt[[ind]] +
           labs(x=hName, y="Predicted")
         if(ccls=="numeric"){
-          gDta[[ind]] <- gDta[[ind]] +
+          gg_plt[[ind]] <- gg_plt[[ind]] +
             geom_point(aes_string(x="var", y="yhat"), ...)
           
           if(smooth){
             
-            gDta[[ind]] <- gDta[[ind]] +
+            gg_plt[[ind]] <- gg_plt[[ind]] +
               geom_smooth(aes_string(x="var", y="yhat"), ...)
             
           }
         }else{
-          gDta[[ind]] <- gDta[[ind]]+
+          gg_plt[[ind]] <- gg_plt[[ind]]+
             geom_boxplot(aes_string(x="var", y="yhat"), color="grey", 
                          ..., outlier.shape = NA)+
             geom_jitter(aes_string(x="var", y="yhat"), 
                         ...)
         }
         # Replace the original colname
-        colnames(object)[chIndx] <- hName
+        colnames(gg_dta)[chIndx] <- hName
       }
     }
-    if(lng == 1) gDta <- gDta[[1]]
+    if(lng == 1) gg_plt <- gg_plt[[1]]
   }    
-  return(gDta)
+  return(gg_plt)
 }
