@@ -25,47 +25,47 @@ test_that("gg_survival survival",{
   #   data(veteran, package = "randomForestSRC")
   #   veteran_rf <- rfsrc(Surv(time, status) ~ ., data = veteran, ntree = 100)
   
-  ## Load the cached forest
-  data(veteran_rf, package="ggRandomForests")
-  
-  # Test the cached forest type
-  expect_is(veteran_rf, "rfsrc")
-  
-  # Test the forest family
-  expect_match(veteran_rf$family, "surv")
-  
-  ## Create the correct gg_error object
-  ggrf.obj<- gg_survival(veteran_rf)
-  
-  # Test object type
-  expect_is(ggrf.obj, "gg_survival")
-  
-  # Test classification dimensions
-  # Same number of rows:
-  expect_equal(ggrf.obj$time, veteran_rf$time.interest)
-  
-  ## Test plotting the gg_error object
-  gg.obj <- plot.gg_survival(ggrf.obj)
-  
-  # Test return is s ggplot object
-  expect_is(gg.obj, "ggplot")
-  
-  
-  ## Create the correct gg_error object
-  ggrf.obj<- gg_survival(veteran_rf, oob=FALSE)
-  
-  # Test object type
-  expect_is(ggrf.obj, "gg_survival")
-  
-  # Test classification dimensions
-  # Same number of rows:
-  expect_equal(ggrf.obj$time, veteran_rf$time.interest)
-  
-  ## Test plotting the gg_error object
-  gg.obj <- plot.gg_survival(ggrf.obj)
-  
-  # Test return is s ggplot object
-  expect_is(gg.obj, "ggplot")
+#   ## Load the cached forest
+#   data(veteran_rf, package="ggRandomForests")
+#   
+#   # Test the cached forest type
+#   expect_is(veteran_rf, "rfsrc")
+#   
+#   # Test the forest family
+#   expect_match(veteran_rf$family, "surv")
+#   
+#   ## Create the correct gg_error object
+#   ggrf.obj<- gg_survival(veteran_rf)
+#   
+#   # Test object type
+#   expect_is(ggrf.obj, "gg_survival")
+#   
+#   # Test classification dimensions
+#   # Same number of rows:
+#   expect_equal(ggrf.obj$time, veteran_rf$time.interest)
+#   
+#   ## Test plotting the gg_error object
+#   gg.obj <- plot.gg_survival(ggrf.obj)
+#   
+#   # Test return is s ggplot object
+#   expect_is(gg.obj, "ggplot")
+#   
+#   
+#   ## Create the correct gg_error object
+#   ggrf.obj<- gg_survival(veteran_rf, oob=FALSE)
+#   
+#   # Test object type
+#   expect_is(ggrf.obj, "gg_survival")
+#   
+#   # Test classification dimensions
+#   # Same number of rows:
+#   expect_equal(ggrf.obj$time, veteran_rf$time.interest)
+#   
+#   ## Test plotting the gg_error object
+#   gg.obj <- plot.gg_survival(ggrf.obj)
+#   
+#   # Test return is s ggplot object
+#   expect_is(gg.obj, "ggplot")
   
 })
 
